@@ -35,6 +35,7 @@ if TYPE_CHECKING:
     from google.api_core.operation import Operation
     from google.api_core.operation_async import AsyncOperation
     from google.api_core.retry import Retry
+    from google.api_core.retry_async import AsyncRetry
     from google.cloud.orchestration.airflow.service_v1.services.environments.pagers import (
         ListEnvironmentsPager,
     )
@@ -59,7 +60,7 @@ class CloudComposerHook(GoogleBaseHook):
         super().__init__(**kwargs)
 
     def get_environment_client(self) -> EnvironmentsClient:
-        """Retrieves client library object that allow access Environments service."""
+        """Retrieve client library object that allow access Environments service."""
         return EnvironmentsClient(
             credentials=self.get_credentials(),
             client_info=CLIENT_INFO,
@@ -67,7 +68,7 @@ class CloudComposerHook(GoogleBaseHook):
         )
 
     def get_image_versions_client(self) -> ImageVersionsClient:
-        """Retrieves client library object that allow access Image Versions service."""
+        """Retrieve client library object that allow access Image Versions service."""
         return ImageVersionsClient(
             credentials=self.get_credentials(),
             client_info=CLIENT_INFO,
@@ -75,7 +76,7 @@ class CloudComposerHook(GoogleBaseHook):
         )
 
     def wait_for_operation(self, operation: Operation, timeout: float | None = None):
-        """Waits for long-lasting operation to complete."""
+        """Wait for long-lasting operation to complete."""
         try:
             return operation.result(timeout=timeout)
         except Exception:
@@ -308,7 +309,7 @@ class CloudComposerAsyncHook(GoogleBaseHook):
     client_options = ClientOptions(api_endpoint="composer.googleapis.com:443")
 
     def get_environment_client(self) -> EnvironmentsAsyncClient:
-        """Retrieves client library object that allow access Environments service."""
+        """Retrieve client library object that allow access Environments service."""
         return EnvironmentsAsyncClient(
             credentials=self.get_credentials(),
             client_info=CLIENT_INFO,
@@ -332,7 +333,7 @@ class CloudComposerAsyncHook(GoogleBaseHook):
         project_id: str,
         region: str,
         environment: Environment | dict,
-        retry: Retry | _MethodDefault = DEFAULT,
+        retry: AsyncRetry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
     ) -> AsyncOperation:
@@ -361,7 +362,7 @@ class CloudComposerAsyncHook(GoogleBaseHook):
         project_id: str,
         region: str,
         environment_id: str,
-        retry: Retry | _MethodDefault = DEFAULT,
+        retry: AsyncRetry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
     ) -> AsyncOperation:
@@ -389,7 +390,7 @@ class CloudComposerAsyncHook(GoogleBaseHook):
         environment_id: str,
         environment: Environment | dict,
         update_mask: dict | FieldMask,
-        retry: Retry | _MethodDefault = DEFAULT,
+        retry: AsyncRetry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
     ) -> AsyncOperation:
