@@ -29,6 +29,7 @@ import warnings
 from copy import deepcopy
 from typing import TYPE_CHECKING, Any, Callable, Generator, Sequence, TypeVar, cast
 
+from deprecated import deprecated
 from google.cloud.dataflow_v1beta3 import GetJobRequest, Job, JobState, JobsV1Beta3AsyncClient, JobView
 from google.cloud.dataflow_v1beta3.types.jobs import ListJobsRequest
 from googleapiclient.discovery import build
@@ -86,7 +87,7 @@ def process_line_and_extract_dataflow_job_id_callback(
 def _fallback_variable_parameter(parameter_name: str, variable_key_name: str) -> Callable[[T], T]:
     def _wrapper(func: T) -> T:
         """
-        Decorator that provides fallback for location from `region` key in `variables` parameters.
+        Fallback for location from `region` key in `variables` parameters.
 
         :param func: function to wrap
         :return: result of the function call
@@ -224,7 +225,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def is_job_running(self) -> bool:
         """
-        Helper method to check if job is still running in dataflow.
+        Check if job is still running in dataflow.
 
         :return: True if job is running.
         """
@@ -236,7 +237,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def _get_current_jobs(self) -> list[dict]:
         """
-        Helper method to get list of jobs that start with job name or id.
+        Get list of jobs that start with job name or id.
 
         :return: list of jobs including id's
         """
@@ -254,7 +255,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def fetch_job_by_id(self, job_id: str) -> dict:
         """
-        Helper method to fetch the job with the specified Job ID.
+        Fetch the job with the specified Job ID.
 
         :param job_id: Job ID to get.
         :return: the Job
@@ -273,7 +274,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def fetch_job_metrics_by_id(self, job_id: str) -> dict:
         """
-        Helper method to fetch the job metrics with the specified Job ID.
+        Fetch the job metrics with the specified Job ID.
 
         :param job_id: Job ID to get.
         :return: the JobMetrics. See:
@@ -292,7 +293,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def _fetch_list_job_messages_responses(self, job_id: str) -> Generator[dict, None, None]:
         """
-        Helper method to fetch ListJobMessagesResponse with the specified Job ID.
+        Fetch ListJobMessagesResponse with the specified Job ID.
 
         :param job_id: Job ID to get.
         :return: yields the ListJobMessagesResponse. See:
@@ -320,7 +321,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def fetch_job_messages_by_id(self, job_id: str) -> list[dict]:
         """
-        Helper method to fetch the job messages with the specified Job ID.
+        Fetch the job messages with the specified Job ID.
 
         :param job_id: Job ID to get.
         :return: the list of JobMessages. See:
@@ -333,7 +334,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def fetch_job_autoscaling_events_by_id(self, job_id: str) -> list[dict]:
         """
-        Helper method to fetch the job autoscaling events with the specified Job ID.
+        Fetch the job autoscaling events with the specified Job ID.
 
         :param job_id: Job ID to get.
         :return: the list of AutoscalingEvents. See:
@@ -374,7 +375,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def _refresh_jobs(self) -> None:
         """
-        Helper method to get all jobs by name.
+        Get all jobs by name.
 
         :return: jobs
         """
@@ -392,7 +393,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def _check_dataflow_job_state(self, job) -> bool:
         """
-        Helper method to check the state of one job in dataflow for this task if job failed raise exception.
+        Check the state of one job in dataflow for this task if job failed raise exception.
 
         :return: True if job is done.
         :raise: Exception
@@ -439,7 +440,7 @@ class _DataflowJobsController(LoggingMixin):
         )
 
     def wait_for_done(self) -> None:
-        """Helper method to wait for result of submitted job."""
+        """Wait for result of submitted job."""
         self.log.info("Start waiting for done.")
         self._refresh_jobs()
         while self._jobs and not all(self._check_dataflow_job_state(job) for job in self._jobs):
@@ -449,7 +450,7 @@ class _DataflowJobsController(LoggingMixin):
 
     def get_jobs(self, refresh: bool = False) -> list[dict]:
         """
-        Returns Dataflow jobs.
+        Return Dataflow jobs.
 
         :param refresh: Forces the latest data to be fetched.
         :return: list of jobs
@@ -462,7 +463,7 @@ class _DataflowJobsController(LoggingMixin):
         return self._jobs
 
     def _wait_for_states(self, expected_states: set[str]):
-        """Waiting for the jobs to reach a certain state."""
+        """Wait for the jobs to reach a certain state."""
         if not self._jobs:
             raise ValueError("The _jobs should be set")
         while True:
@@ -485,7 +486,7 @@ class _DataflowJobsController(LoggingMixin):
             time.sleep(self._poll_sleep)
 
     def cancel(self) -> None:
-        """Cancels or drains current job."""
+        """Cancel or drains current job."""
         self._jobs = [
             job for job in self.get_jobs() if job["currentState"] not in DataflowJobStatus.TERMINAL_STATES
         ]
@@ -560,13 +561,22 @@ class DataflowHook(GoogleBaseHook):
         )
 
     def get_conn(self) -> build:
-        """Returns a Google Cloud Dataflow service object."""
+        """Return a Google Cloud Dataflow service object."""
         http_authorized = self._authorize()
         return build("dataflow", "v1b3", http=http_authorized, cache_discovery=False)
 
     @_fallback_to_location_from_variables
     @_fallback_to_project_id_from_variables
     @GoogleBaseHook.fallback_to_default_project_id
+    @deprecated(
+        reason=(
+            "This method is deprecated. "
+            "Please use `airflow.providers.apache.beam.hooks.beam.start.start_java_pipeline` "
+            "to start pipeline and `providers.google.cloud.hooks.dataflow.DataflowHook.wait_for_done` "
+            "to wait for the required pipeline state."
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
     def start_java_dataflow(
         self,
         job_name: str,
@@ -580,7 +590,7 @@ class DataflowHook(GoogleBaseHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> None:
         """
-        Starts Dataflow java job.
+        Start Dataflow java job.
 
         :param job_name: The name of the job.
         :param variables: Variables passed to the job.
@@ -593,16 +603,6 @@ class DataflowHook(GoogleBaseHook):
         :param on_new_job_id_callback: Callback called when the job ID is known.
         :param location: Job location.
         """
-        warnings.warn(
-            """"This method is deprecated.
-            Please use `airflow.providers.apache.beam.hooks.beam.start.start_java_pipeline`
-            to start pipeline and `providers.google.cloud.hooks.dataflow.DataflowHook.wait_for_done`
-            to wait for the required pipeline state.
-            """,
-            AirflowProviderDeprecationWarning,
-            stacklevel=3,
-        )
-
         name = self.build_dataflow_job_name(job_name, append_job_name)
 
         variables["jobName"] = name
@@ -642,7 +642,7 @@ class DataflowHook(GoogleBaseHook):
         environment: dict | None = None,
     ) -> dict:
         """
-        Starts Dataflow template job.
+        Start Dataflow template job.
 
         :param job_name: The name of the job.
         :param variables: Map of job runtime environment options.
@@ -767,7 +767,7 @@ class DataflowHook(GoogleBaseHook):
         on_new_job_callback: Callable[[dict], None] | None = None,
     ) -> dict:
         """
-        Starts flex templates with the Dataflow pipeline.
+        Start flex templates with the Dataflow pipeline.
 
         :param body: The request body. See:
             https://cloud.google.com/dataflow/docs/reference/rest/v1b3/projects.locations.flexTemplates/launch#request-body
@@ -816,6 +816,15 @@ class DataflowHook(GoogleBaseHook):
     @_fallback_to_location_from_variables
     @_fallback_to_project_id_from_variables
     @GoogleBaseHook.fallback_to_default_project_id
+    @deprecated(
+        reason=(
+            "This method is deprecated. "
+            "Please use `airflow.providers.apache.beam.hooks.beam.start.start_python_pipeline` "
+            "to start pipeline and `providers.google.cloud.hooks.dataflow.DataflowHook.wait_for_done` "
+            "to wait for the required pipeline state."
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
     def start_python_dataflow(
         self,
         job_name: str,
@@ -831,7 +840,7 @@ class DataflowHook(GoogleBaseHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ):
         """
-        Starts Dataflow job.
+        Start Dataflow job.
 
         :param job_name: The name of the job.
         :param variables: Variables passed to the job.
@@ -859,16 +868,6 @@ class DataflowHook(GoogleBaseHook):
         :param on_new_job_id_callback: Callback called when the job ID is known.
         :param location: Job location.
         """
-        warnings.warn(
-            """This method is deprecated.
-            Please use `airflow.providers.apache.beam.hooks.beam.start.start_python_pipeline`
-            to start pipeline and `providers.google.cloud.hooks.dataflow.DataflowHook.wait_for_done`
-            to wait for the required pipeline state.
-            """,
-            AirflowProviderDeprecationWarning,
-            stacklevel=3,
-        )
-
         name = self.build_dataflow_job_name(job_name, append_job_name)
         variables["job_name"] = name
         variables["region"] = location
@@ -892,7 +891,7 @@ class DataflowHook(GoogleBaseHook):
 
     @staticmethod
     def build_dataflow_job_name(job_name: str, append_job_name: bool = True) -> str:
-        """Builds Dataflow job name."""
+        """Build Dataflow job name."""
         base_job_name = str(job_name).replace("_", "-")
 
         if not re.fullmatch(r"[a-z]([-a-z0-9]*[a-z0-9])?", base_job_name):
@@ -919,7 +918,7 @@ class DataflowHook(GoogleBaseHook):
         variables: dict | None = None,
     ) -> bool:
         """
-        Helper method to check if jos is still running in dataflow.
+        Check if jos is still running in dataflow.
 
         :param name: The name of the job.
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
@@ -955,7 +954,7 @@ class DataflowHook(GoogleBaseHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> None:
         """
-        Cancels the job with the specified name prefix or Job ID.
+        Cancel the job with the specified name prefix or Job ID.
 
         Parameter ``name`` and ``job_id`` are mutually exclusive.
 
@@ -990,7 +989,7 @@ class DataflowHook(GoogleBaseHook):
         on_new_job_callback: Callable[[dict], None] | None = None,
     ):
         """
-        Starts Dataflow SQL query.
+        Start Dataflow SQL query.
 
         :param job_name: The unique name to assign to the Cloud Dataflow job.
         :param query: The SQL query to execute.
@@ -1083,7 +1082,7 @@ class DataflowHook(GoogleBaseHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> dict:
         """
-        Gets the job with the specified Job ID.
+        Get the job with the specified Job ID.
 
         :param job_id: Job ID to get.
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
@@ -1107,7 +1106,7 @@ class DataflowHook(GoogleBaseHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> dict:
         """
-        Gets the job metrics with the specified Job ID.
+        Get the job metrics with the specified Job ID.
 
         :param job_id: Job ID to get.
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
@@ -1132,7 +1131,7 @@ class DataflowHook(GoogleBaseHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> list[dict]:
         """
-        Gets the job messages with the specified Job ID.
+        Get the job messages with the specified Job ID.
 
         :param job_id: Job ID to get.
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
@@ -1156,7 +1155,7 @@ class DataflowHook(GoogleBaseHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> list[dict]:
         """
-        Gets the job autoscaling events with the specified Job ID.
+        Get the job autoscaling events with the specified Job ID.
 
         :param job_id: Job ID to get.
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
@@ -1266,7 +1265,7 @@ class AsyncDataflowHook(GoogleBaseAsyncHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> Job:
         """
-        Gets the job with the specified Job ID.
+        Get the job with the specified Job ID.
 
         :param job_id: Job ID to get.
         :param project_id: the Google Cloud project ID in which to start a job.
@@ -1301,7 +1300,7 @@ class AsyncDataflowHook(GoogleBaseAsyncHook):
         location: str = DEFAULT_DATAFLOW_LOCATION,
     ) -> JobState:
         """
-        Gets the job status with the specified Job ID.
+        Get the job status with the specified Job ID.
 
         :param job_id: Job ID to get.
         :param project_id: the Google Cloud project ID in which to start a job.
