@@ -289,7 +289,7 @@ class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         return hyperparameter_tuning_job
 
     def on_kill(self) -> None:
-        """Callback called when the operator is killed; cancel any running job."""
+        """Act as a callback called when the operator is killed; cancel any running job."""
         if self.hook:
             self.hook.cancel_hyperparameter_tuning_job()
 
