@@ -109,7 +109,7 @@ class BigQueryToSqlBaseOperator(BaseOperator):
         """Return a concrete SQL Hook (a PostgresHook for instance)."""
 
     def persist_links(self, context: Context) -> None:
-        """This function persists the connection to the SQL provider."""
+        """Persist the connection to the SQL provider."""
 
     def execute(self, context: Context) -> None:
         big_query_hook = BigQueryHook(
